@@ -60,13 +60,12 @@ static char vcid[] __attribute__ ((unused)) =
 "$Id: disk.c,v 1.10 1997/08/22 12:35:38 rnhodek Exp $";
 #endif /* lint */
 
+#define _FILE_OFFSET_BITS 64
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #include <unistd.h>
-#ifdef __linux__
-#include <asm/unistd.h>
-#endif
 #include <fcntl.h>
 #include <errno.h>
 
@@ -81,44 +80,13 @@ static char vcid[] __attribute__ ((unused)) =
 /*
  * sseek: seek to specified sector - return 0 on failure
  *
- * For >4GB disks lseek needs a > 32bit arg, and we have to use llseek.
+ * For >4GB disks lseek needs a > 32bit arg.
  * On the other hand, a 32 bit sector number is OK until 2TB.
- * The routines _llseek and sseek below are the only ones that
- * know about the loff_t type.
+ *
+ * Thanks to _FILE_OFFSET_BITS, we can have GNU libc use an 64bit off_t even on
+ * 32bit platforms.
  */
 
-#ifdef __NR__llseek
-
-static _syscall5( int, _llseek, uint, fd, ulong, hi, ulong, lo,
-		  loff_t *, res, uint, wh );
-
-/* seek to a sector */
-int sseek( unsigned int fd, unsigned long s )
-{
-    loff_t in, out;
-
-    in = (loff_t)s * SECTOR_SIZE;
-    out = 1;
-
-    if (_llseek (fd, in>>32, in & 0xffffffff, &out, SEEK_SET) != 0) {
-	perror( "llseek" );
-	fprintf( stderr, "seek error - cannot seek to sector %lu\n", s );
-	return 0;
-    }
-
-    if (in != out) {
-	fprintf( stderr, "seek error: wanted 0x%08x%08x, got 0x%08x%08x\n",
-		 (uint)(in>>32), (uint)(in & 0xffffffff),
-		 (uint)(out>>32), (uint)(out & 0xffffffff) );
-	return 0;
-    }
-    return 1;
-}
-
-#else
-
-/* Sorry, kernel doesn't know _llseek call :-((( */
-
 int sseek( unsigned int fd, unsigned long s )
 {
     off_t in, out;
@@ -137,8 +105,6 @@ int sseek( unsigned int fd, unsigned long s )
     return 1;
 }
 
-#endif
-
 /* read one sector */
 void sread( char *buffer, unsigned long secno )
 {
