@@ -1275,7 +1275,7 @@ void verify(void)
 	}
     }
     if (xpart_fmt == xfmt_ICD && j > 0) {
-	printf( "Error: ICD format and extended partitions found (??)\n" );
+	printf( "Error: ICD format and extended partitions found (?!?)\n" );
 	++errors;
     }
     else if (j > 1) {
